/*!
 * carte v1
 * by E-magineurs
 *
 */

// Uses Node, AMD or browser globals to create a module.

function throttle(fn, wait) {

    var time = Date.now();
    return function () {

        if ((time + wait - Date.now()) < 0) {
            fn();
            time = Date.now();
        }
    }
}

(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['jquery'], factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like environments that support module.exports,
        // like Node.
        module.exports = factory(require('jquery'));
    } else {
        // Browser globals (root is window)
        root.carte = factory(root.jQuery);
    }
}(this, function ($) {

    function carte(options) {
        this.init();

        // options
        this.options = $.extend({}, this.constructor.defaults);
        this.option(options);

    }
    carte.defaults = {
        element: '.slider',
        titreNav: 'h2',
        fullpage: true,
        directionTransition: 'top',
        carte: "#carte"
    }
    carte.prototype.option = function (options) {
        $.extend(this.options, options);
        //console.log(this.options);
    }
    carte.prototype.init = function () {
        var self = this;

        $(document).ready(function () {
            self.build();
        });

    }


    /***************************
    
    Initialisation
    
    ***************************/

    carte.prototype.build = function () {
        let self = this;

        let touchEvents;
        if (Modernizr.touchevents) {
            touchEvents = true
        } else {
            touchEvents = false
        }
        console.log('touchevents: ' + touchEvents);

        /* bloquer le scroll pour du pleine page */
        $('html').addClass('overflow');

        /* assignation des variables principales 
        element : objets du slider (attention contnient toutes les instances)
        sliderSldies, liste des slides de l'élément
        numberItem : nombre de slide
        navigation : liste des boutons
        
        */
        this.$carte = $(self.options.carte)
        this.$carteContainer = $(self.options.carte).children();
        this.$carteimage = this.$carte.find('img').clone();

        

        this.$element = $(self.options.element).addClass('fullpage');
        this.$sliderSlides = this.$element.children().wrapAll('<div class="fullpage-inner"></div>');
        this.$sliderSlides.addClass('fullpage-item')
        this.$currentSlide = this.$sliderSlides.first().addClass('active');
        this.$currentPos = 0;
        this.$numberItems = this.$sliderSlides.length;


        let miniMap = $('<div id="minimap"></div>');
        let minimapZone = $('<div id="minimapZone"></div>')
        miniMap.append(this.$carteimage).append(minimapZone);
        $('body').append(miniMap);

        minimapZone.css('width', (100 / (this.$numberItems - 1)) + "%");

        this.$miniMap = minimap;
        console.log(this.$miniMap);
        this.$miniMapZone = minimapZone;

        this.$navigation = self.createNav(this.$miniMap);
        
        let elem = this;

        /* creation des elements de transtions */
        this.$sliderSlides.each(function () {
            
            
            let radius = 145; // radius of the circle
            let fields = $(this).find('.sailor ul').children('li'),
                width = 288,
                height = 288,
                angle = 5,
                step = (2 * Math.PI) / fields.length;
            let iterator = 1;
            fields.each(function () {
                var x = Math.round(width / 2 + radius * Math.cos(angle)),
                    y = Math.round(height / 2 + radius * Math.sin(angle));
                $(this).css({
                    left: x + 'px',
                    top: y + 'px'
                });
                if(iterator > Math.round(fields.length/2)){
                    $(this).addClass('lefted');
                }
                angle += step;
                iterator++;
            });

            let cursorLayout = $('<div class="cursorLayout"></div>');


            let cursorCircle = $('<div class="circle" data-direction="top"></div>');
            cursorLayout.append(cursorCircle);
            /* scrolldir : direction du scroll de la souri utilisateur */
            let scrollDir = 'top';
            let heightPage = $(window).width();


            cursorLayout.on("mousemove", moveCircle)

            function moveCircle(e) {

                TweenLite.to(cursorCircle, 0.3, {
                    css: {
                        left: e.pageX,
                        top: e.pageY
                    }
                });

                pageY = e.pageX;
                
                if(elem.$currentPos == 0){
                    if(e.pageX > ($(window).width())/2){
                        cursorCircle.addClass('hidden');
                    }
                    else{
                        cursorCircle.removeClass('hidden');
                    }
                }
                
                else if(elem.$currentPos == (elem.$sliderSlides.length-1)){
                    
                    if(e.pageX < ($(window).width())/2){
                        cursorCircle.addClass('hidden');
                    }
                    else{
                        cursorCircle.removeClass('hidden');
                    }
                }
                else{
                    cursorCircle.removeClass('hidden');
                }

            }
            cursorLayout.on("mousemove", throttle(detectDirection, 200));

            function detectDirection() {

                if (pageY > heightPage / 2) {
                    cursorDirection = "top";
                } else {
                    cursorDirection = "bottom";
                }
            }




            $(this).append(cursorLayout);

            let flag = false;


            /* quand on arrive sur la zone */
            cursorLayout.on("mouseover", function () {
                flag = true;

                TweenLite.to(cursorCircle, 0.4, {
                    scale: 1,
                    autoAlpha: 1
                })

            })


            cursorLayout.on("mouseout", function () {
                flag = false;
                TweenLite.to(cursorCircle, 0.4, {
                    scale: 0.1,
                    autoAlpha: 0
                })

            })


            /* gestion du haut et du bas */
            cursorCircle.on("mousedown", function () {
                console.log('click');
                if (cursorDirection == 'top') {

                    self.prev();
                } else {

                    self.next();
                }

            })

            if (touchEvents == true) {
                elem.$element.swipe({

                    swipe: function (event, direction, distance, duration, fingerCount, fingerData) {
                        console.log(direction);
                        if (direction == 'left') {
                            self.prev();
                        } else if (direction == 'right') {
                            self.next();
                        }
                    },
                    //Default is 75px, set to 0 for demo so any distance triggers swipe
                    threshold: 75
                });
            }





        })

        /* Detection de la direction du scroll */
        document.getElementById('main').addEventListener("wheel", function (e) {

            let event = e;

            if (event.deltaY > 0) {
                scrollDir = 'bottom';
            } else {
                scrollDir = 'top';
            }

        }, true);

        /* ajout de l'événetement scroll */
        document.getElementById('main').addEventListener("wheel", throttle(callback, 450), true);

        /* prev ou next en fonction de la direction, après throttle */
        function callback() {

            if (scrollDir == 'top') {
                console.log('prev');
                self.prev();
            } else {
                console.log('next');
                self.next();
            }

        }

        $("#loader").fadeOut();

    }

    /***************************
    
    slidethis : gestion des animations entre slides
    
    ***************************/

    carte.prototype.slideThis = function (classDirection, position) {
        let self = this;
        self.$sliderSlides
            .removeClass('slide-top-reverse')
            .removeClass('slide-bottom-reverse')
            .addClass(classDirection)
            .removeClass('active');

        $(self.$sliderSlides[position])
            .removeClass('slide-top')
            .removeClass('slide-bottom')
            .addClass(classDirection + '-reverse')
            .addClass('active');
        self.$currentSlide = $(self.$sliderSlides[position]);
        self.$currentPos = position;
    }

    /***************************
    
    prev : go to slide précédente
    
    ***************************/
    carte.prototype.prev = function () {
        let self = this;
        let classDirection = 'slide-bottom';
        let position;
        let topPosition;
        self.$sliderSlides.each(function () {

            if ($(this).hasClass('active')) {
                position = $(this).index() - 1;
            }

        })

        topPosition = self.$sliderSlides.eq(position).attr('data-centertop');

        if (position >= 0) {
            self.$navigation.children('button').removeClass('active');
            self.$navigation.children('button').eq(position).addClass('active');
            self.slideThis(classDirection, position);
            let cartepos = (50 / (self.$numberItems - 1)) * position;
            let mappos = ((100 * self.$numberItems) - 200) * position * (1 / (self.$numberItems - 1));

            //self.$carte.css('transform', "translateX(" + cartepos + "%) translateY(" + topPosition + "%)")
            TweenLite.to(self.$carte, 0.3, {
                x: cartepos+'%',
                y:topPosition+'%'
            });
            //self.$miniMapZone.css('transform', "translateX(-" + mappos + "%) translateY(-" + topPosition + "%)")
            TweenLite.to(self.$miniMapZone, 0.3, {
                x: '-' + mappos + '%',
                y:'-' + topPosition + '%'
            });
        }




    }

    /***************************
    
    next : go to slide suivante
    
    ***************************/
    carte.prototype.next = function () {
        let self = this;
        let classDirection = 'slide-top';
        let position;
        let topPosition;
        self.$sliderSlides.each(function () {
            if ($(this).hasClass('active')) {
                position = $(this).index() + 1;

            }

        })

        topPosition = self.$sliderSlides.eq(position).attr('data-centertop');

        self.$navigation.children('button').removeClass('active');
        self.$navigation.children('button').eq(position).addClass('active');
        if (position < self.$numberItems) {
            self.slideThis(classDirection, position);
            let cartepos = (50 / (self.$numberItems - 1)) * position;
            let mappos = ((100 * self.$numberItems) - 200) * position * (1 / (self.$numberItems - 1));

            //self.$carte.css('transform', "translateX(" + cartepos + "%) translateY(" + topPosition + "%)")
            TweenLite.to(self.$carte, 0.3, {
                x: cartepos+'%',
                y:topPosition+'%'
            });
            //self.$miniMapZone.css('transform', "translateX(-" + mappos + "%) translateY(-" + topPosition + "%)")
            TweenLite.to(self.$miniMapZone, 0.3, {
                x: '-' + mappos + '%',
                y:'-' + topPosition + '%'
            });
        }


    }

    /***************************
    
    goToSlide : go to slide choisie, utilisée par les boutons de navigation
    
    ***************************/
    carte.prototype.goToSlide = function (elem, position) {
        let self = elem;
        let currentPos;
        let topPosition;
        self.$navigation.children('button').removeClass('active');
        self.$navigation.children('button').eq(position).addClass('active');
        self.$sliderSlides.each(function () {
            if ($(this).hasClass('active')) {
                currentPos = $(this).index();
            }
        })

        let classDirection;
        if (currentPos > position) {
            classDirection = 'slide-top';
        } else {
            classDirection = 'slide-bottom';
        }

        topPosition = self.$sliderSlides.eq(position).attr('data-centertop');

        let cartepos = (50 / (self.$numberItems - 1)) * position;
        let mappos = ((100 * self.$numberItems) - 200) * position * (1 / (self.$numberItems - 1));

        //self.$carte.css('transform', "translateX(" + cartepos + "%) translateY(" + topPosition + "%)")
        TweenLite.to(self.$carte, 0.3, {
            x: cartepos+'%',
            y:topPosition+'%'
        });
        //self.$miniMapZone.css('transform', "translateX(-" + mappos + "%) translateY(-" + topPosition + "%)")

        TweenLite.to(self.$miniMapZone, 0.3, {
                x: '-' + mappos + '%',
                y:'-' + topPosition + '%'
            });

        self.slideThis(classDirection, position);
    }

    /***************************
    
    createNav : création de la liste des boutons de navigation
    
    ***************************/
    carte.prototype.createNav = function (elem) {
        let self = this;
        let navigation = $('<div class="fullpage-nav"></div>');
        console.log(elem);
        $(elem).append(navigation);

        self.$sliderSlides.each(function (index) {
            let fullpageDot = $('<button>' + index + '</button>');
            fullpageDot.on("click", function () {
                let currentBtn = $(this);
                self.goToSlide(self, index);

            });
            navigation.append(fullpageDot)
        })

        return navigation;

    }

    return carte;
}));
