/*!
 * fullpageImg v1
 * by E-magineurs
 *
 */

// Uses Node, AMD or browser globals to create a module.

function throttle(fn, wait) {

    var time = Date.now();
    return function () {

        if ((time + wait - Date.now()) < 0) {
            fn();
            time = Date.now();
        }
    }
}

(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['jquery'], factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like environments that support module.exports,
        // like Node.
        module.exports = factory(require('jquery'));
    } else {
        // Browser globals (root is window)
        root.fullpageImg = factory(root.jQuery);
    }
}(this, function ($) {

    function fullpageImg(options) {
        this.init();

        // options
        this.options = $.extend({}, this.constructor.defaults);
        this.option(options);

    }
    fullpageImg.defaults = {
        element: '.slider',
        titreNav: 'h2',
        fullpage: true,
        directionTransition: 'top'
    }
    fullpageImg.prototype.option = function (options) {
        $.extend(this.options, options);
        //console.log(this.options);
    }
    fullpageImg.prototype.init = function () {
        var self = this;

        $(document).ready(function () {
            self.build();
        });

    }


    /***************************
    
    Initialisation
    
    ***************************/

    fullpageImg.prototype.build = function () {
        let self = this;

        let touchEvents;
        if (Modernizr.touchevents) {
            this.touchEvents = true
        } else {
            this.touchEvents = false
        }

        /* bloquer le scroll pour du pleine page */
        $('html').addClass('overflow');

        /* assignation des variables principales 
        element : objets du slider (attention contnient toutes les instances)
        sliderSldies, liste des slides de l'élément
        numberItem : nombre de slide
        navigation : liste des boutons
        
        */
        this.$element = $(self.options.element).addClass('fullpage');
        this.$sliderSlides = this.$element.children().wrapAll('<div class="fullpage-inner"></div>');
        this.$sliderSlides.addClass('fullpage-item')
        this.$sliderSlides.first().addClass('active');
        this.$numberItems = this.$sliderSlides.length;
        this.$navigation = self.createNav();

        /* scrolldir : direction du scroll de la souri utilisateur */
        let scrollDir = 'top';


        self.createSlide();

        /* Detection de la direction du scroll */
        document.getElementById('main').addEventListener("wheel", function (e) {

            let event = e;

            if (event.deltaY > 0) {
                scrollDir = 'bottom';
            } else {
                scrollDir = 'top';
            }

        }, true);

        /* ajout de l'événetement scroll */
        document.getElementById('main').addEventListener("wheel", throttle(callback, 450), true);

        /* prev ou next en fonction de la direction, après throttle */
        function callback() {

            if (scrollDir == 'top') {
                console.log('prev');
                self.prev();
            } else {
                console.log('next');
                self.next();
            }

        }

    }

    /***************************
    
    slidethis : gestion des animations entre slides
    
    ***************************/

    fullpageImg.prototype.createSlide = function () {
        let self = this;
        let heightPage = $(window).height();
        /* creation des elements de transtions */
        self.$sliderSlides.each(function () {
            let smallLayout = $('<div class="fullpage-layout small-layout "></div>');
            let bigLayout = $('<div class="fullpage-layout big-layout "></div>');
            let imgLayout = $('<div class="img-layout"></div>');

            let cursorLayout = $('<div class="cursorLayout"></div>');
            let cursorCircle = $('<div class="circle" data-direction="top"></div>');
            let cursorDirection = 'top';
            let pageY;

            $(this).find('span').addClass(' textillate');
            $(this).find('h2').addClass(' textillate-2');
            cursorLayout.append(cursorCircle);


            $(this).append(smallLayout).append(bigLayout).append(cursorLayout).append(imgLayout);

            let flag = false;


            /* quand on arrive sur la zone */
            cursorLayout.on("mouseover", function () {
                flag = true;

                TweenLite.to(cursorCircle, 0.4, {
                    scale: 1,
                    autoAlpha: 1
                })

            })
            cursorLayout.on("mousemove", moveCircle)

            function moveCircle(e) {

                TweenLite.to(cursorCircle, 0.3, {
                    css: {
                        left: e.pageX,
                        top: e.pageY
                    }
                });
                pageY = e.pageY;

            }
            cursorLayout.on("mousemove", throttle(detectDirection, 200));

            function detectDirection() {

                if (pageY > heightPage / 2) {
                    cursorDirection = "bottom";
                } else {
                    cursorDirection = "top";
                }
            }

            cursorLayout.on("mouseout", function () {
                flag = false;
                TweenLite.to(cursorCircle, 0.4, {
                    scale: 0.1,
                    autoAlpha: 0
                })

            })


            /* gestion du haut et du bas */
            cursorCircle.on("mousedown", function () {

                if (cursorDirection == 'top') {

                    self.prev();
                } else {

                    self.next();
                }

            })

            if (self.touchEvents == true) {
                cursorLayout.swipe({

                    swipe: function (event, direction, distance, duration, fingerCount, fingerData) {

                        if (direction == 'up') {
                            self.next();
                        } else if (direction == 'down') {
                            self.prev();
                        }
                    },
                    //Default is 75px, set to 0 for demo so any distance triggers swipe
                    threshold: 75
                });
            }
            TweenLite.fromTo($(this).children('.small-layout'), 0.7, {
                scaleY: 1,
                // y:'100%',
                transformOrigin: "top"
            }, {
                scaleY: 0,
                //y:0
            })
            TweenLite.fromTo($(this).children('.big-layout'), 0.4, {
                scaleY: 1,
                // y:'100%',
                transformOrigin: "top"
            }, {
                scaleY: 0,
                //  y:0
            })


        })

    }


    /***************************
    
    slidethis : gestion des animations entre slides
    
    ***************************/

    fullpageImg.prototype.slideThis = function (classDirection, position) {
        let self = this;
        self.$navigation.children('li').children('button').removeClass('active');
        self.$navigation.children('li').children('button').eq(position).addClass('active');
        self.$sliderSlides
            /*.removeClass('slide-top-reverse')
            .removeClass('slide-bottom-reverse')
            .addClass(classDirection)*/
            .removeClass('active');

        $(self.$sliderSlides[position])
            /*.removeClass('slide-top')
            .removeClass('slide-bottom')
            .addClass(classDirection + '-reverse')*/
            .addClass('active');
        TweenLite.fromTo($(self.$sliderSlides[position]), 1.4, {
                opacity:0
            }, {
                opacity:1

            })
        var tl = new TimelineLite();
        var tl2 = new TimelineLite();
        if (classDirection == 'slide-top') {
            tl.fromTo($(self.$sliderSlides[position]).children('.small-layout'), 0.7, {
                scaleY: 0,
                y: 0,
                transformOrigin: "top"
            }, {
                scaleY: 1,
                y: '50%',
                ease: Power1.easeIn
            }).to($(self.$sliderSlides[position]).children('.small-layout'), 0.7, {
                scaleY: 0,
                y: '100%',
                ease: Power1.easeOut

            })
            tl2.fromTo($(self.$sliderSlides[position]).children('.big-layout'), 0.4, {
                scaleY: 0,
                y: 0,
                transformOrigin: "top"
            }, {
                scaleY: 1,
                y: '50%',
                ease: Power1.easeIn
            }).to($(self.$sliderSlides[position]).children('.big-layout'), 0.4, {
                scaleY: 0,
                y: '100%',
                ease: Power1.easeOut

            })
        } else {
            tl.fromTo($(self.$sliderSlides[position]).children('.small-layout'), 0.7, {
                scaleY: 0,
                y: '100%',
                transformOrigin: "0 0",
            }, {
                scaleY: 0.7,
                y: '0',
                ease: Power1.easeIn

            }).to($(self.$sliderSlides[position]).children('.small-layout'), 0.7, {
                scaleY: 0,
                y: '0',
                transformOrigin: "0 0",
                ease: Power1.easeOut

            })
            tl2.fromTo($(self.$sliderSlides[position]).children('.big-layout'), 0.4, {
                scaleY: 0,
                y: '100%',
                transformOrigin: "0 0"
            }, {
                scaleY: 0.7,
                y: '0',
                ease: Power1.easeIn

            }).to($(self.$sliderSlides[position]).children('.big-layout'), 0.4, {
                scaleY: 0,
                y: 0,
                transformOrigin: "0 0",
                ease: Power1.easeOut

            })
        }
        self.animateSlide($(self.$sliderSlides[position]));
    }

    /***************************
    
    prev : go to slide précédente
    
    ***************************/
    fullpageImg.prototype.prev = function () {
        let self = this;
        let classDirection = 'slide-top';
        let position;
        self.$sliderSlides.each(function () {
            if ($(this).hasClass('active')) {
                position = $(this).index() - 1;
            }
        })

        if (position >= 0) {

            self.slideThis(classDirection, position);
        }



    }

    /***************************
    
    next : go to slide suivante
    
    ***************************/
    fullpageImg.prototype.next = function () {
        let self = this;
        let classDirection = 'slide-bottom';
        let position;
        self.$sliderSlides.each(function () {
            if ($(this).hasClass('active')) {
                position = $(this).index() + 1;
            }
        })

        if (position < self.$numberItems) {
            self.slideThis(classDirection, position);
        }


    }

    /***************************
    
    animateSlide : Anime la slide en paramètre
    
    ***************************/

    fullpageImg.prototype.animateSlide = function (elem) {
        let self = this;
       
        self.texting(elem.find('.textillate'), elem.find('.textillate-2'));


    }


    /***************************
    
    texting : gestion des animations entre slides
    
    ***************************/

    fullpageImg.prototype.texting = function (elem, elem2) {
        let self = this;


        console.log(elem);
        
        elem.each(function(){
            console.log($(this))
            let animatedText = $(this).textillate({
                initialDelay: 0.3,
                autoStart: false,
                minDisplayTime: 5000,
                in: {
                    delayScale: 1.5,
                    effect: 'fadeInUp'
                }
            });
            animatedText.textillate('start');
            animatedText.on('inAnimationBegin.tlt', function () {
                animatedText.removeClass('opacity');
            });
        })

        


        let animatedText2 = elem2.textillate({
            initialDelay: 0,
            autoStart: false,
            minDisplayTime: 5000,
            in: {
                delayScale: 1.5,
                effect: 'fadeInUp'
            }
        });
        animatedText2.textillate('start');
        animatedText2.on('inAnimationBegin.tlt', function () {
            animatedText2.removeClass('opacity');

        });




        //return animatedText;

    }

    /***************************
    
    goToSlide : go to slide choisie, utilisée par les boutons de navigation
    
    ***************************/
    fullpageImg.prototype.goToSlide = function (elem, position) {
        let self = elem;
        let currentPos;

        self.$navigation.children('button').removeClass('active');
        self.$navigation.children('button').eq(position).addClass('active');
        self.$sliderSlides.each(function () {
            if ($(this).hasClass('active')) {
                currentPos = $(this).index();
            }
        })

        let classDirection;
        if (currentPos > position) {
            classDirection = 'slide-top';
        } else {
            classDirection = 'slide-bottom';
        }

        self.slideThis(classDirection, position);
    }

    /***************************
    
    createNav : création de la liste des boutons de navigation
    
    ***************************/
    fullpageImg.prototype.createNav = function (elem) {
        let self = this;
        let navigation = $('<ul class="fullpage-nav"></ul>');
        let iterator = 0;
        self.$element.append(navigation);

        self.$sliderSlides.each(function (index) {
            let activeitem = "";
            if (iterator == 0) {
                activeitem = 'class="active"';
            }

            let fullpageDot = $('<li><button ' + activeitem + '><span class="sr-only"> Slide numéro ' + index + '</span><span class="tip">' + $(this).find('h2').text() + '</span></button></li>');
            fullpageDot.on("click", function () {
                let currentBtn = $(this);
                self.goToSlide(self, index);

            });
            navigation.append(fullpageDot);
            iterator++;
        })

        return navigation;

    }

    return fullpageImg;
}));
